Engine

Struct Engine 

pub struct Engine { /* private fields */ }
A Base58 Encoder/Decoder Engine.

Implementations

Source

impl Engine

pub const fn new(alphabet: &[u8; 58]) -> Result<Self, Error>

Constructs a new Engine with a custom alphabet. Returns Error::WrongAlphabet if the alphabet contains duplicates.

pub const fn config(&self) -> &Config

Returns the internal configuration.

pub const fn encoded_len(&self, input_len: usize) -> usize

Returns the maximum possible length of the encoded data. Base58 expansion is ~137%. We add padding for safety.

pub const fn decoded_len(&self, input_len: usize) -> usize

Returns the maximum possible length of the decoded data. Base58 ’1’s map 1:1 to bytes. We cannot assume compression. The worst-case decoded size is equal to the input string length.

pub fn encode_into<T: AsRef<[u8]>>( &self, input: T, output: &mut [u8], ) -> Result<usize, Error>

Encodes input into the output buffer. Returns the actual number of bytes written.

pub fn decode_into<T: AsRef<[u8]>>( &self, input: T, output: &mut [u8], ) -> Result<usize, Error>

Decodes input into the output buffer. Returns the actual number of bytes written.

pub fn encode<T: AsRef<[u8]>>(&self, input: T) -> Result<String, Error>

Available on crate feature std only.

Encodes input into the newly allocated String. Returns the String.

pub fn decode<T: AsRef<[u8]>>(&self, input: T) -> Result<Vec<u8>, Error>

Available on crate feature std only.

Decodes input into the newly allocated Vec<u8>. Returns the Vec<u8>.